import {
  select,
  selectAll,
  scaleBand,
  scaleLinear,
  range,
  max,
} from 'd3';

const w = 600;
const h = 250;

const dataset = [
  { key: 0, value: 5 }, //dataset is now an array of objects.
  { key: 1, value: 10 }, //Each object has a 'key' and a 'value'.
  { key: 2, value: 13 },
  { key: 3, value: 19 },
  { key: 4, value: 21 },
  { key: 5, value: 25 },
  { key: 6, value: 22 },
  { key: 7, value: 18 },
  { key: 8, value: 15 },
  { key: 9, value: 13 },
  { key: 10, value: 11 },
  { key: 11, value: 12 },
  { key: 12, value: 15 },
  { key: 13, value: 20 },
  { key: 14, value: 18 },
  { key: 15, value: 17 },
  { key: 16, value: 16 },
  { key: 17, value: 18 },
  { key: 18, value: 23 },
  { key: 19, value: 25 },
];

const xScale = scaleBand()
  .domain(range(dataset.length))
  .rangeRound([0, w])
  .paddingInner(0.05);

const yScale = scaleLinear()
  .domain([0, max(dataset, (d) => d.value)])
  .range([0, h]);

const key = (d) => d.key;

const svg = select('body')
  .append('svg')
  .attr('width', w)
  .attr('height', h);

svg
  .selectAll('rect')
  .data(dataset, key)
  .join('rect')
  .attr('x', (d, i) => xScale(i))
  .attr('y', (d) => h - yScale(d.value))
  .attr('height', (d) => yScale(d.value))
  .attr('width', xScale.bandwidth())
  .attr('fill', 'lightblue');

select('input').on('change', function (event) {
  const threshold = +select(this).node().value;
  selectAll('rect')
  	.attr('fill', 'lightblue')
    .filter((d) => d.value < threshold)
    .transition()
    .duration(500)
    .attr('fill', 'darkblue');
});
